function u = visualizeCycles(G, flux)
% Checks if there are cycles in the flux-field and plots them if there are.
% SYNOPSIS:
%   u = visualizeCycles(G, flux)
%
% REQUIRED PARAMETERS:
%   G       - Grid data structure as described by grid_structure.
%   flux    - Vector of fluxes where element i represent the flux through
%             face i. 
%
% RETURNS:
%   u           - Vector containg the size of the cycles
%   N           - The number of cycles
%   nmax        - The size of the largest cycle
%   cyclefree   - Logical parameter, true if there are no cycles and false
%                 if there are cycles.

%{
Copyright 2012 Christine M. Ø. Haugland.

This file is part of the Hybrid Mimetic and Multipoint module(HybridMethods).
HybridMethods is a module for the MATLAB Reservoir Simulation Toolbox (MRST).

HybridMethods is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

HybridMethods is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with HybridMethods.  If not, see <http://www.gnu.org/licenses/>.

%} 

locN = double(G.faces.neighbors);

fluxcopy = flux;
for i = 1:length(locN)
    if(locN(i,1) == 0)
        locN(i,1) = locN(i,2);
    elseif(locN(i,2) == 0)
        locN(i,2) = locN(i,1);
    end
end

for i = 1:length(fluxcopy)
    if(abs(fluxcopy(i))<=max(abs(flux))*1e-13)
        fluxcopy(i) = 0;
    end
    if(fluxcopy(i)<0)
        temp = locN(i,1);
        locN(i,1) = locN(i,2);
        locN(i,2) = temp;
        newtemp = fluxcopy(i);
        fluxcopy(i) = -1*newtemp;
    end
end


adj = sparse(locN(:,1), locN(:,2), fluxcopy);

fluxmatr = adj;

for i = 1:G.cells.num
    adj(i,i) = 1;
end

[p, q, r] = dmperm(adj);
if(length(r) == G.cells.num+1)
    mono = true;
else
    mono = false;
end


if mono == false
    u = diff(r)-1;
    figure
    spy(fluxmatr);
    b = find(u > 0);
    begincyc = r(b);
    w = u(b);
    h = u(b);
    for j = 1:length(w)
        rectangle('position', [begincyc(j), begincyc(j), w(j) h(j)], 'EdgeColor', 'r');
    end
end

end